/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include "TStatusBar.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component ("Central Component"),
                                         pHelloLabel(0),
                                         pCloseButton(0)
{
    pHelloLabel = new Label("Hello Label", tr("Привет, мир!"));
    pHelloLabel->setColour(Label::outlineColourId, Colours::black);
    pHelloLabel->addMouseListener(this, false);
    addAndMakeVisible(pHelloLabel);
    pHelloLabel->setFont(Font(38.0000f, Font::bold));
    // Ориентация текста ярлыка - по центру виджета
    pHelloLabel->setJustificationType(Justification::centred);
    // Зпрет на редактирование содержимого ярлыка
    pHelloLabel->setEditable(false, false, false);
    // Синий цвет шрифта
    pHelloLabel->setColour(Label::textColourId, Colours::blue);
    pHelloLabel->setColour(TextEditor::backgroundColourId, Colours::azure);

    pCloseButton = new TextButton("Close Button");
    addAndMakeVisible(pCloseButton);
    pCloseButton->setButtonText(tr("Закрыть"));
    // Устанавливаем в качестве слушателя кнопки
    // сам компонент-контейнер
    pCloseButton->addListener(this);
    pCloseButton->addMouseListener(this, false);
    // Создаём панель состояния
    pStatusBar = new TStatusBar();
    addAndMakeVisible(pStatusBar);

    setSize (400, 200);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pHelloLabel->setBounds(0, 0, proportionOfWidth(1.0000f), proportionOfHeight(0.7000f));
    pCloseButton->setBounds(getWidth() - 20 - 100, getHeight() - 55, 100, 25);
    pStatusBar->setBounds(0, proportionOfHeight(1.0000f) - 25, proportionOfWidth(1.0000f), 25);
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    // Если нажата кнопка "Закрыть"...
    if(pButton == pCloseButton)
    {
        // выходим из программы
        JUCEApplication::quit();
    }
}
//---------------------------------------------------------------------
void TCentralComponent::mouseMove(const MouseEvent& Event)
{
    if(Event.originalComponent == pHelloLabel)
    {
        pStatusBar->ShowHint(tr("Привет, мир!"));
    }
    else if(Event.source.getComponentUnderMouse() == pCloseButton)
    {
        pStatusBar->ShowHint(tr("Нажмите, чтобы завершить работу программы"));
    }
    else
    {
        pStatusBar->ShowHint("");
    }
}
//---------------------------------------------------------------------
