/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TStatusBar.h"
#include "../JuceLibraryCode/JuceHeader.h" 
//---------------------------------------------------------------------
TStatusBar::TStatusBar() : Component("StatusBar"),
                           Timer()
{
    pMessagesLabel = new Label("MessagesLabel", "");
    addAndMakeVisible(pMessagesLabel);
    pMessagesLabel->setColour(Label::backgroundColourId, Colours::azure);
    
    pDateTimeLabel = new Label("DateTimeLabel", "");
    addAndMakeVisible(pDateTimeLabel);
    // Дата и время отображаются у правого края окна программы
    pDateTimeLabel->setJustificationType(Justification::right);
    pDateTimeLabel->setColour(Label::backgroundColourId, Colours::azure);
    
    // В первый раз отображаем дату и время
    this->timerCallback();
    // Вызываем функцию timerCallback каждую секунду
    this->startTimer(1000);
}
//---------------------------------------------------------------------
TStatusBar::~TStatusBar()
{
    // При завершении работы останавливаем таймер
    this->stopTimer();
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TStatusBar::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TStatusBar::resized()
{
    pMessagesLabel->setBounds(0, proportionOfHeight(1.0000f) - 25, proportionOfWidth(0.6000f), 25);
    pDateTimeLabel->setBounds(proportionOfWidth(0.6500f), proportionOfHeight(1.0000f) - 25, proportionOfWidth(0.3500f), 25);
}
//---------------------------------------------------------------------
// Функция форматирования даты (выводит предшествующий ноль в однозначных цифрах)
String TStatusBar::sFormatDate(int iNumber)
{
    // Преобразуем число в соответствующую строку
    String sNumber = String(iNumber);
    switch(iNumber)
    {
        case 0:
        case 1:
        case 2:
        case 3:
        case 4:
        case 5:
        case 6:
        case 7:
        case 8:
        case 9:
        {
            // Если число в диапазоне от 0 до 9,
            // добавим в начало соответствующей ему строки ноль
            sNumber = (String("0") += sNumber);
            break;
        }
        default:
        {
            break;
        }
    }
    return sNumber;
}
//---------------------------------------------------------------------
void TStatusBar::timerCallback()
{
    // Получаем текущую дату и время
    Time DateTime = Time::getCurrentTime();
    // Форматируем день (число месяца)
    String sDay = sFormatDate(DateTime.getDayOfMonth());
    // Форматируем месяц
    String sMonth = sFormatDate(DateTime.getMonth() + 1);
    // Получаем год в виде строки
    String sYear = String(DateTime.getYear());
    // Форматируем час, минуты и секунды текущей даты
    String sHours = sFormatDate(DateTime.getHours());
    String sMinutes = sFormatDate(DateTime.getMinutes());
    String sSeconds = sFormatDate(DateTime.getSeconds());
    // Формируем результирующую строку
    String sDateTime = sDay + "." + sMonth + "." + sYear + " - " + sHours + ":" + sMinutes + ":" + sSeconds;
    // Отображаем отформатированные дату и время
    pDateTimeLabel->setText(sDateTime, false);
}
//---------------------------------------------------------------------
void TStatusBar::ShowHint(String sHint)
{
    // Отображаем строку подсказки, полученную в качестве параметра
    pMessagesLabel->setText(sHint, false);
}
//---------------------------------------------------------------------
